==> gidfwizard-snap-beta-0.2.3.tar.gz: gidfwizard-snap-beta-0.2.3/generalform.h <==
/*
  EDMA IDFWizard GNOMIZED Version 0.1.0
  Copyright (C) 1998-1999 David Martnez Oliveira
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
  
 */

#ifndef GENERAL_FORM_H
#define GENERAL_FORM_H

#include <gnome.h>

#include <edma.h>
/*
#include <edma/portable.h>
#include <edma/dlink.h>
#include <edma/dynlink.h>
*/
//#include "interface.h"
#define MAX_LANG 64
typedef EChar  IDS[256];

typedef struct general_widgets
{
  GtkWidget       *table;
  GtkWidget       *ClassName;
  GtkWidget       *ModuleName;
  GtkWidget       *TargetLanguage;
  GtkWidget       *OS;
  GtkWidget       *Machine;
  GtkWidget       *SIUProxy;
  GtkWidget       *IsSIUProxy;
  GtkWidget       *IDFParser;
  GtkWidget       *IsIDFParser;
  GtkWidget       *IsEMI;
  GList           *languages;
  EUint32         n;
  IDS             lang_imp_classes[MAX_LANG];
  IDS             lang_make_classes[MAX_LANG];
  IDS             lang_desc[MAX_LANG];
  GList           *sos;
  GList           *machines;
  GList           *proxies;
  GList           *parsers;
  // Functions
  ESint32         (*build_form)(struct general_widgets *,GtkWidget *);
} GeneralWidgets;

ESint32 InitGeneralForm (GeneralWidgets *gw);
ESint32 BuildGeneralForm (GeneralWidgets *gw,GtkWidget *note);

ESint32 GeneralGetClassName(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetModuleName(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetTargetLanguage(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetOS(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetMachine(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetSIUProxy(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetIDFParser(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetIsProxy (GeneralWidgets *gw);
ESint32 GeneralGetIsParser (GeneralWidgets *gw);
ESint32 GeneralGetIsEMI (GeneralWidgets *gw);

ESint32 GeneralSetClassName(GeneralWidgets*,EPChar);
ESint32 GeneralSetModuleName(GeneralWidgets*,EPChar);
#endif

==> gidfwizard-snap-beta-0.5.0.tar.gz: gidfwizard-snap-beta-0.5.0/generalform.h <==
/*
  EDMA IDFWizard GNOMIZED Version 0.1.0
  Copyright (C) 1998-1999 David Martnez Oliveira
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
  
 */

#ifndef GENERAL_FORM_H
#define GENERAL_FORM_H

#include <gnome.h>

#include <edma.h>
#define MAX_LANG 64
typedef EChar  IDS[256];

typedef struct general_widgets
{
  GtkWidget       *table;
  GtkWidget       *ClassName;
  GtkWidget       *ModuleName;
  GtkWidget       *NameSpace;
  GtkWidget       *TargetLanguage;
  GtkWidget       *OS;
  GtkWidget       *Machine;
  GtkWidget       *SIUProxy;
  GtkWidget       *IsSIUProxy;
  GtkWidget       *IDFParser;
  GtkWidget       *IsIDFParser;
  GtkWidget       *IsEMI;
  GtkWidget       *MajorVersion;
  GtkWidget       *MinorVersion;
  GList           *languages;
  EUint32         n;
  IDS             lang_imp_classes[MAX_LANG];
  IDS             lang_make_classes[MAX_LANG];
  IDS             lang_desc[MAX_LANG];
  GList           *sos;
  GList           *machines;
  GList           *proxies;
  GList           *parsers;
  /* Functions*/
  ESint32         (*build_form)(struct general_widgets *,GtkWidget *);
} GeneralWidgets;

ESint32 InitGeneralForm (GeneralWidgets *gw);
ESint32 BuildGeneralForm (GeneralWidgets *gw,GtkWidget *note);

ESint32 GeneralGetClassName(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetNameSpace(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetModuleName(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetTargetLanguage(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetOS(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetMachine(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetSIUProxy(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetIDFParser(GeneralWidgets *gw,EPChar r);
ESint32 GeneralGetIsProxy (GeneralWidgets *gw);
ESint32 GeneralGetIsParser (GeneralWidgets *gw);
ESint32 GeneralGetIsEMI (GeneralWidgets *gw);
ESint32 GeneralGetMajorVersion (GeneralWidgets *gw);
ESint32 GeneralGetMinorVersion (GeneralWidgets *gw);

ESint32 GeneralSetClassName(GeneralWidgets*,EPChar);
ESint32 GeneralSetNameSpace(GeneralWidgets*,EPChar);
ESint32 GeneralSetModuleName(GeneralWidgets*,EPChar);

ESint32 GeneralSetMajorVersion (GeneralWidgets *gw, ESint32 v);
ESint32 GeneralSetMinorVersion (GeneralWidgets *gw, ESint32 v);
#endif
